==> idoit-documents-1.8.zip: src/classes/modules/document/classmap.php <==
<?php
/**
 * Classmap for "document" generated on 2023-08-30
 */

return array (
  'idoit\\Module\\Document\\Console\\Command\\CompileDocumentsCommand' => 'src/classes/modules/document/src/Console/Command/CompileDocumentsCommand.php',
  'idoit\\Module\\Document\\Console\\Command\\DocumentsCommand' => 'src/classes/modules/document/src/Console/Command/DocumentsCommand.php',
  'isys_ajax_handler_document' => 'src/classes/modules/document/handler/ajax/isys_ajax_handler_document.class.php',
  'isys_api_model_document' => 'src/classes/modules/document/api/isys_api_model_document.class.php',
  'isys_api_model_document_documents' => 'src/classes/modules/document/api/isys_api_model_document_documents.class.php',
  'isys_auth_document' => 'src/classes/modules/document/auth/isys_auth_document.class.php',
  'isys_cmdb_dao_category_g_document' => 'src/classes/modules/document/cmdb/dao/global/isys_cmdb_dao_category_g_document.class.php',
  'isys_cmdb_dao_list_catg_document' => 'src/classes/modules/document/cmdb/dao/list/isys_cmdb_dao_list_catg_document.class.php',
  'isys_cmdb_ui_category_g_document' => 'src/classes/modules/document/cmdb/ui/global/isys_cmdb_ui_category_g_document.class.php',
  'isys_dashboard_widgets_document_last_revisions' => 'src/classes/modules/document/dashboard/widgets/last_revisions/isys_dashboard_widgets_document_last_revisions.class.php',
  'isys_document_compiler' => 'src/classes/modules/document/compiler/isys_document_compiler.class.php',
  'isys_document_compiler_chapter' => 'src/classes/modules/document/compiler/isys_document_compiler_chapter.class.php',
  'isys_document_compiler_document' => 'src/classes/modules/document/compiler/isys_document_compiler_document.class.php',
  'isys_document_compiler_model' => 'src/classes/modules/document/compiler/model/isys_document_compiler_model.class.php',
  'isys_document_compiler_model_chapter' => 'src/classes/modules/document/compiler/model/isys_document_compiler_model_chapter.class.php',
  'isys_document_compiler_model_document' => 'src/classes/modules/document/compiler/model/isys_document_compiler_model_document.class.php',
  'isys_document_compiler_placeholder' => 'src/classes/modules/document/compiler/placeholder/isys_document_compiler_placeholder.class.php',
  'isys_document_compiler_placeholder_category' => 'src/classes/modules/document/compiler/placeholder/isys_document_compiler_placeholder_category.class.php',
  'isys_document_compiler_placeholder_image' => 'src/classes/modules/document/compiler/placeholder/isys_document_compiler_placeholder_image.class.php',
  'isys_document_compiler_placeholder_property' => 'src/classes/modules/document/compiler/placeholder/isys_document_compiler_placeholder_property.class.php',
  'isys_document_compiler_placeholder_report' => 'src/classes/modules/document/compiler/placeholder/isys_document_compiler_placeholder_report.class.php',
  'isys_document_compiler_placeholder_template_var' => 'src/classes/modules/document/compiler/placeholder/isys_document_compiler_placeholder_template_var.class.php',
  'isys_document_dao' => 'src/classes/modules/document/dao/isys_document_dao.class.php',
  'isys_document_dao_chapters' => 'src/classes/modules/document/dao/isys_document_dao_chapters.class.php',
  'isys_document_dao_components' => 'src/classes/modules/document/dao/isys_document_dao_components.class.php',
  'isys_document_dao_revision' => 'src/classes/modules/document/dao/isys_document_dao_revision.class.php',
  'isys_document_dao_templates' => 'src/classes/modules/document/dao/isys_document_dao_templates.class.php',
  'isys_document_export' => 'src/classes/modules/document/export/isys_document_export.class.php',
  'isys_document_export_html' => 'src/classes/modules/document/export/isys_document_export_html.class.php',
  'isys_document_export_model' => 'src/classes/modules/document/export/isys_document_export_model.class.php',
  'isys_document_export_pdf' => 'src/classes/modules/document/export/isys_document_export_pdf.class.php',
  'isys_document_export_template_json' => 'src/classes/modules/document/export/isys_document_export_template_json.class.php',
  'isys_document_format_html' => 'src/classes/modules/document/format/isys_document_format_html.class.php',
  'isys_document_format_pdf' => 'src/classes/modules/document/format/isys_document_format_pdf.class.php',
  'isys_document_format_text' => 'src/classes/modules/document/format/isys_document_format_text.class.php',
  'isys_document_formattable' => 'src/classes/modules/document/format/isys_document_formattable.class.php',
  'isys_document_view_online_repository' => 'src/classes/modules/document/views/isys_document_view_online_repository.class.php',
  'isys_handler_document' => 'src/classes/modules/document/handler/controller/isys_handler_document.class.php',
  'isys_module_document' => 'src/classes/modules/document/isys_module_document.class.php',
  'isys_module_document_install' => 'src/classes/modules/document/install/isys_module_document_install.class.php',
  'isys_popup_document_create_document' => 'src/classes/modules/document/popups/isys_popup_document_create_document.class.php',
  'isys_popup_document_placeholder_external_object' => 'src/classes/modules/document/popups/isys_popup_document_placeholder_external_object.class.php',
  'isys_popup_document_placeholder_floorplan' => 'src/classes/modules/document/popups/isys_popup_document_placeholder_floorplan.class.php',
  'isys_popup_document_placeholder_images' => 'src/classes/modules/document/popups/isys_popup_document_placeholder_images.class.php',
  'isys_popup_document_placeholder_object' => 'src/classes/modules/document/popups/isys_popup_document_placeholder_object.class.php',
  'isys_popup_document_placeholder_report' => 'src/classes/modules/document/popups/isys_popup_document_placeholder_report.class.php',
  'isys_popup_document_placeholder_template_vars' => 'src/classes/modules/document/popups/isys_popup_document_placeholder_template_vars.class.php',
  'isys_popup_document_revision_comment' => 'src/classes/modules/document/popups/isys_popup_document_revision_comment.class.php',
  'isys_popup_document_template_duplicate' => 'src/classes/modules/document/popups/isys_popup_document_template_duplicate.class.php',
  'isys_popup_document_template_import' => 'src/classes/modules/document/popups/isys_popup_document_template_import.class.php',
);

==> idoit-documents-1.11.zip: src/classes/modules/document/classmap.php <==
<?php
/**
 * Classmap for "document" generated on 2024-07-04
 */

return [
  'idoit\\Module\\Document\\Console\\Command\\CompileDocumentsCommand' => 'src/classes/modules/document/src/Console/Command/CompileDocumentsCommand.php',
  'idoit\\Module\\Document\\Console\\Command\\DocumentsCommand' => 'src/classes/modules/document/src/Console/Command/DocumentsCommand.php',
  'isys_ajax_handler_document' => 'src/classes/modules/document/handler/ajax/isys_ajax_handler_document.class.php',
  'isys_api_model_document' => 'src/classes/modules/document/api/isys_api_model_document.class.php',
  'isys_api_model_document_documents' => 'src/classes/modules/document/api/isys_api_model_document_documents.class.php',
  'isys_auth_document' => 'src/classes/modules/document/auth/isys_auth_document.class.php',
  'isys_cmdb_dao_category_g_document' => 'src/classes/modules/document/cmdb/dao/global/isys_cmdb_dao_category_g_document.class.php',
  'isys_cmdb_dao_list_catg_document' => 'src/classes/modules/document/cmdb/dao/list/isys_cmdb_dao_list_catg_document.class.php',
  'isys_cmdb_ui_category_g_document' => 'src/classes/modules/document/cmdb/ui/global/isys_cmdb_ui_category_g_document.class.php',
  'isys_dashboard_widgets_document_last_revisions' => 'src/classes/modules/document/dashboard/widgets/last_revisions/isys_dashboard_widgets_document_last_revisions.class.php',
  'isys_document_compiler' => 'src/classes/modules/document/compiler/isys_document_compiler.class.php',
  'isys_document_compiler_chapter' => 'src/classes/modules/document/compiler/isys_document_compiler_chapter.class.php',
  'isys_document_compiler_document' => 'src/classes/modules/document/compiler/isys_document_compiler_document.class.php',
  'isys_document_compiler_model' => 'src/classes/modules/document/compiler/model/isys_document_compiler_model.class.php',
  'isys_document_compiler_model_chapter' => 'src/classes/modules/document/compiler/model/isys_document_compiler_model_chapter.class.php',
  'isys_document_compiler_model_document' => 'src/classes/modules/document/compiler/model/isys_document_compiler_model_document.class.php',
  'isys_document_compiler_placeholder' => 'src/classes/modules/document/compiler/placeholder/isys_document_compiler_placeholder.class.php',
  'isys_document_compiler_placeholder_category' => 'src/classes/modules/document/compiler/placeholder/isys_document_compiler_placeholder_category.class.php',
  'isys_document_compiler_placeholder_image' => 'src/classes/modules/document/compiler/placeholder/isys_document_compiler_placeholder_image.class.php',
  'isys_document_compiler_placeholder_property' => 'src/classes/modules/document/compiler/placeholder/isys_document_compiler_placeholder_property.class.php',
  'isys_document_compiler_placeholder_report' => 'src/classes/modules/document/compiler/placeholder/isys_document_compiler_placeholder_report.class.php',
  'isys_document_compiler_placeholder_template_var' => 'src/classes/modules/document/compiler/placeholder/isys_document_compiler_placeholder_template_var.class.php',
  'isys_document_dao' => 'src/classes/modules/document/dao/isys_document_dao.class.php',
  'isys_document_dao_chapters' => 'src/classes/modules/document/dao/isys_document_dao_chapters.class.php',
  'isys_document_dao_components' => 'src/classes/modules/document/dao/isys_document_dao_components.class.php',
  'isys_document_dao_revision' => 'src/classes/modules/document/dao/isys_document_dao_revision.class.php',
  'isys_document_dao_templates' => 'src/classes/modules/document/dao/isys_document_dao_templates.class.php',
  'isys_document_export' => 'src/classes/modules/document/export/isys_document_export.class.php',
  'isys_document_export_html' => 'src/classes/modules/document/export/isys_document_export_html.class.php',
  'isys_document_export_model' => 'src/classes/modules/document/export/isys_document_export_model.class.php',
  'isys_document_export_pdf' => 'src/classes/modules/document/export/isys_document_export_pdf.class.php',
  'isys_document_export_template_json' => 'src/classes/modules/document/export/isys_document_export_template_json.class.php',
  'isys_document_format_html' => 'src/classes/modules/document/format/isys_document_format_html.class.php',
  'isys_document_format_pdf' => 'src/classes/modules/document/format/isys_document_format_pdf.class.php',
  'isys_document_format_text' => 'src/classes/modules/document/format/isys_document_format_text.class.php',
  'isys_document_formattable' => 'src/classes/modules/document/format/isys_document_formattable.class.php',
  'isys_document_view_online_repository' => 'src/classes/modules/document/views/isys_document_view_online_repository.class.php',
  'isys_module_document' => 'src/classes/modules/document/isys_module_document.class.php',
  'isys_module_document_install' => 'src/classes/modules/document/install/isys_module_document_install.class.php',
  'isys_popup_document_create_document' => 'src/classes/modules/document/popups/isys_popup_document_create_document.class.php',
  'isys_popup_document_placeholder_external_object' => 'src/classes/modules/document/popups/isys_popup_document_placeholder_external_object.class.php',
  'isys_popup_document_placeholder_floorplan' => 'src/classes/modules/document/popups/isys_popup_document_placeholder_floorplan.class.php',
  'isys_popup_document_placeholder_images' => 'src/classes/modules/document/popups/isys_popup_document_placeholder_images.class.php',
  'isys_popup_document_placeholder_object' => 'src/classes/modules/document/popups/isys_popup_document_placeholder_object.class.php',
  'isys_popup_document_placeholder_report' => 'src/classes/modules/document/popups/isys_popup_document_placeholder_report.class.php',
  'isys_popup_document_placeholder_template_vars' => 'src/classes/modules/document/popups/isys_popup_document_placeholder_template_vars.class.php',
  'isys_popup_document_revision_comment' => 'src/classes/modules/document/popups/isys_popup_document_revision_comment.class.php',
  'isys_popup_document_template_duplicate' => 'src/classes/modules/document/popups/isys_popup_document_template_duplicate.class.php',
  'isys_popup_document_template_import' => 'src/classes/modules/document/popups/isys_popup_document_template_import.class.php',
];
